using System;
using System.Diagnostics;
using Bytescout.Spreadsheet;
using Bytescout.Spreadsheet.Charts;

namespace CSharp
{
    class Program
    {
        static void Main(string[] args)
        {
            // Create new Spreadsheet object
            Spreadsheet spreadsheet = new Spreadsheet();
            spreadsheet.RegistrationName = "demo";
            spreadsheet.RegistrationKey = "demo";

            // Add new worksheet
            Worksheet sheet = spreadsheet.Workbook.Worksheets.Add("Sample");

            // Add few random numbers
            int length = 10;
            Random rnd = new Random();
            for (int i = 0; i < length; i++)
            {
                sheet.Cell(i, 0).Value = rnd.Next(1, 10);
                sheet.Cell(i, 1).Value = rnd.Next(1, 5);
            }

            // Add charts to worksheet
            Chart radarChart = sheet.Charts.AddChartAndFitInto(1, 3, 16, 9, ChartType.Radar);
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 0, length - 1, 0)));
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 1, length - 1, 1)));

            radarChart = sheet.Charts.AddChartAndFitInto(1, 10, 16, 16, ChartType.RadarMarkers);
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 0, length - 1, 0)));
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 1, length - 1, 1)));

            radarChart = sheet.Charts.AddChartAndFitInto(1, 17, 16, 23, ChartType.RadarFilled);
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 0, length - 1, 0)));
            radarChart.SeriesCollection.Add(new Series(sheet.Range(0, 1, length - 1, 1)));

            // Save it as XLS
            spreadsheet.SaveAs("Output.xls");

            // Close the document
            spreadsheet.Close();

            // Cleanup
            spreadsheet.Dispose();

            // Open generated XLS file in default associated application
            Process.Start("Output.xls");
        }
    }
}
